<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>CSVColumnConfigurationDialog</name>
    <message>
        <location filename="../src/ui/CSVColumnConfigurationDialog.ui" line="14"/>
        <source>Select the role of the column</source>
        <translation>Выберите роль данных в столбце</translation>
    </message>
    <message>
        <location filename="../src/ui/CSVColumnConfigurationDialog.ui" line="23"/>
        <source>Column role</source>
        <translation>Роль</translation>
    </message>
    <message>
        <location filename="../src/ui/CSVColumnConfigurationDialog.ui" line="29"/>
        <source>Annotation start position</source>
        <translation>Начальная позиция</translation>
    </message>
    <message>
        <location filename="../src/ui/CSVColumnConfigurationDialog.ui" line="39"/>
        <source>Add offset</source>
        <translation>Смещение</translation>
    </message>
    <message>
        <location filename="../src/ui/CSVColumnConfigurationDialog.ui" line="52"/>
        <source> bp</source>
        <translation> сим</translation>
    </message>
    <message>
        <location filename="../src/ui/CSVColumnConfigurationDialog.ui" line="65"/>
        <source>Annotation end position</source>
        <translation>Конечная позиция</translation>
    </message>
    <message>
        <location filename="../src/ui/CSVColumnConfigurationDialog.ui" line="75"/>
        <source>Inclusive</source>
        <translation>Включительно</translation>
    </message>
    <message>
        <location filename="../src/ui/CSVColumnConfigurationDialog.ui" line="85"/>
        <source>Annotation length</source>
        <translation>Длина аннотации</translation>
    </message>
    <message>
        <location filename="../src/ui/CSVColumnConfigurationDialog.ui" line="92"/>
        <source>Complement strand mark</source>
        <translation type="unfinished">Комплементарное направление</translation>
    </message>
    <message>
        <location filename="../src/ui/CSVColumnConfigurationDialog.ui" line="102"/>
        <source>Mark value</source>
        <translation>Метка</translation>
    </message>
    <message>
        <location filename="../src/ui/CSVColumnConfigurationDialog.ui" line="119"/>
        <source>Annotation name</source>
        <translation>Имя аннотации</translation>
    </message>
    <message>
        <location filename="../src/ui/CSVColumnConfigurationDialog.ui" line="126"/>
        <source>Qualifier</source>
        <translation>Квалификатор</translation>
    </message>
    <message>
        <location filename="../src/ui/CSVColumnConfigurationDialog.ui" line="147"/>
        <source>Ignore this column</source>
        <translation>Не использовать этот столбец</translation>
    </message>
    <message>
        <location filename="../src/ui/CSVColumnConfigurationDialog.ui" line="205"/>
        <source>Ok</source>
        <translation>Принять</translation>
    </message>
    <message>
        <location filename="../src/ui/CSVColumnConfigurationDialog.ui" line="212"/>
        <source>Cancel</source>
        <translation>Отменить</translation>
    </message>
</context>
<context>
    <name>ExportChromatogramDialog</name>
    <message>
        <location filename="../src/ui/ExportChromatogramDialog.ui" line="14"/>
        <source>Export chromatogram file</source>
        <translation type="unfinished">Экспортировать хроматограмму</translation>
    </message>
    <message>
        <location filename="../src/ui/ExportChromatogramDialog.ui" line="25"/>
        <source>Export to file</source>
        <translation type="unfinished">Записать в файл</translation>
    </message>
    <message>
        <location filename="../src/ui/ExportChromatogramDialog.ui" line="35"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../src/ui/ExportChromatogramDialog.ui" line="42"/>
        <source>File format to use</source>
        <translation type="unfinished">Используемый формат файла</translation>
    </message>
    <message>
        <location filename="../src/ui/ExportChromatogramDialog.ui" line="56"/>
        <source>Reversed</source>
        <translation type="unfinished">Обратный</translation>
    </message>
    <message>
        <location filename="../src/ui/ExportChromatogramDialog.ui" line="66"/>
        <source>Complemented</source>
        <translation type="unfinished">Комплементарный</translation>
    </message>
    <message>
        <location filename="../src/ui/ExportChromatogramDialog.ui" line="75"/>
        <source>Add document to the project</source>
        <translation type="unfinished">Добавить документ к проекту</translation>
    </message>
    <message>
        <location filename="../src/ui/ExportChromatogramDialog.ui" line="113"/>
        <source>Export</source>
        <translation type="unfinished">Экспорт</translation>
    </message>
    <message>
        <location filename="../src/ui/ExportChromatogramDialog.ui" line="123"/>
        <source>Cancel</source>
        <translation type="unfinished">Отменить</translation>
    </message>
</context>
<context>
    <name>ImportAnnotationsFromCSVDialog</name>
    <message>
        <location filename="../src/ui/ImportAnnotationsFromCSVDialog.ui" line="14"/>
        <source>Import annotations from CSV</source>
        <translation>Импортировать аннотации из CSV</translation>
    </message>
    <message>
        <location filename="../src/ui/ImportAnnotationsFromCSVDialog.ui" line="25"/>
        <source>File to read</source>
        <translation>Входной файл</translation>
    </message>
    <message>
        <location filename="../src/ui/ImportAnnotationsFromCSVDialog.ui" line="35"/>
        <location filename="../src/ui/ImportAnnotationsFromCSVDialog.ui" line="60"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ImportAnnotationsFromCSVDialog.ui" line="44"/>
        <source>Results</source>
        <translation>Результаты</translation>
    </message>
    <message>
        <location filename="../src/ui/ImportAnnotationsFromCSVDialog.ui" line="50"/>
        <source>Result file</source>
        <translation>Выходной файл</translation>
    </message>
    <message>
        <location filename="../src/ui/ImportAnnotationsFromCSVDialog.ui" line="67"/>
        <source>File format</source>
        <translation>Формат файла</translation>
    </message>
    <message>
        <location filename="../src/ui/ImportAnnotationsFromCSVDialog.ui" line="77"/>
        <source>Add result file to project</source>
        <translation>Добавить результат к проекту</translation>
    </message>
    <message>
        <location filename="../src/ui/ImportAnnotationsFromCSVDialog.ui" line="96"/>
        <location filename="../src/ui/ImportAnnotationsFromCSVDialog.ui" line="111"/>
        <source>Column separator</source>
        <translation>Разделитель столбцов</translation>
    </message>
    <message>
        <location filename="../src/ui/ImportAnnotationsFromCSVDialog.ui" line="103"/>
        <source>File parsing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/ImportAnnotationsFromCSVDialog.ui" line="140"/>
        <source>,</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ImportAnnotationsFromCSVDialog.ui" line="150"/>
        <source>Guess</source>
        <translation>Определить</translation>
    </message>
    <message>
        <location filename="../src/ui/ImportAnnotationsFromCSVDialog.ui" line="157"/>
        <source>Script</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/ImportAnnotationsFromCSVDialog.ui" line="177"/>
        <source>Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/ImportAnnotationsFromCSVDialog.ui" line="184"/>
        <source>First  lines to skip</source>
        <translation>Пропускать сначала</translation>
    </message>
    <message>
        <location filename="../src/ui/ImportAnnotationsFromCSVDialog.ui" line="207"/>
        <source>Do not skip</source>
        <translation>Не пропускать</translation>
    </message>
    <message>
        <location filename="../src/ui/ImportAnnotationsFromCSVDialog.ui" line="210"/>
        <source> line(s)</source>
        <translation>строка(и)</translation>
    </message>
    <message>
        <location filename="../src/ui/ImportAnnotationsFromCSVDialog.ui" line="220"/>
        <source>Skip all lines starts with the text</source>
        <translation>Пропускать строки, начинающиеся с текста</translation>
    </message>
    <message>
        <location filename="../src/ui/ImportAnnotationsFromCSVDialog.ui" line="246"/>
        <source>#</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ImportAnnotationsFromCSVDialog.ui" line="266"/>
        <source>Remove quotes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/ImportAnnotationsFromCSVDialog.ui" line="283"/>
        <source>Default annotation name</source>
        <translation>Имя аннотации по умолчанию</translation>
    </message>
    <message>
        <location filename="../src/ui/ImportAnnotationsFromCSVDialog.ui" line="296"/>
        <source>misc_feature</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ImportAnnotationsFromCSVDialog.ui" line="259"/>
        <source>Interpret multiple separators like a single separator (try when separator is a whitespace character)</source>
        <translation>Интерпретировать повторяющийся разделитель как одиночный (используйте, когда разделителем служит пробел)</translation>
    </message>
    <message>
        <location filename="../src/ui/ImportAnnotationsFromCSVDialog.ui" line="313"/>
        <source>Results preview</source>
        <translation>Просмотр результата</translation>
    </message>
    <message>
        <location filename="../src/ui/ImportAnnotationsFromCSVDialog.ui" line="333"/>
        <source>Preview</source>
        <translation>Просмотр</translation>
    </message>
    <message>
        <location filename="../src/ui/ImportAnnotationsFromCSVDialog.ui" line="360"/>
        <source>Raw file preview:</source>
        <translation>Просмотр &quot;сырого&quot; файла:</translation>
    </message>
    <message>
        <location filename="../src/ui/ImportAnnotationsFromCSVDialog.ui" line="410"/>
        <source>Run</source>
        <translation>Запустить</translation>
    </message>
    <message>
        <location filename="../src/ui/ImportAnnotationsFromCSVDialog.ui" line="417"/>
        <source>Cancel</source>
        <translation>Отменить</translation>
    </message>
</context>
<context>
    <name>U2::ADVExportContext</name>
    <message>
        <location filename="../src/ExportSequenceViewItems.cpp" line="78"/>
        <source>Export selected sequence region...</source>
        <translation>Экспорт выбранных регионов последовательности...</translation>
    </message>
    <message>
        <location filename="../src/ExportSequenceViewItems.cpp" line="81"/>
        <source>Export sequence of selected annotations...</source>
        <translation>Экспорт последовательностей выбранных аннотаций...</translation>
    </message>
    <message>
        <source>Export annotations to CSV format...</source>
        <translation type="obsolete">Экспорт аннотаций в CSV...</translation>
    </message>
    <message>
        <location filename="../src/ExportSequenceViewItems.cpp" line="84"/>
        <source>Export annotations...</source>
        <translation>Экспортировать аннотации...</translation>
    </message>
    <message>
        <location filename="../src/ExportSequenceViewItems.cpp" line="87"/>
        <source>Align selected annotations...</source>
        <translation>Выровнять выбранные аннотации...</translation>
    </message>
    <message>
        <location filename="../src/ExportSequenceViewItems.cpp" line="90"/>
        <source>Align selected annotations (amino acids)...</source>
        <translation type="unfinished">Вырвнять выбранные аннотации (аминокислоты)...</translation>
    </message>
    <message>
        <location filename="../src/ExportSequenceViewItems.cpp" line="93"/>
        <source>Align selected sequence regions...</source>
        <translation>Выровнять выбранные последовательности...</translation>
    </message>
    <message>
        <location filename="../src/ExportSequenceViewItems.cpp" line="96"/>
        <source>Align selected sequence regions (amino acids)...</source>
        <translation type="unfinished">Выравнять выбранные регионы (аминокислоты)...</translation>
    </message>
    <message>
        <location filename="../src/ExportSequenceViewItems.cpp" line="99"/>
        <source>Export sequences by &apos;id&apos;</source>
        <translation type="unfinished">Экспортировать последовательности по &apos;id&apos;</translation>
    </message>
    <message>
        <location filename="../src/ExportSequenceViewItems.cpp" line="101"/>
        <source>Export sequences by &apos;accession&apos;</source>
        <translation type="unfinished">Экспортировать последовательности по &apos;accession&apos;</translation>
    </message>
    <message>
        <location filename="../src/ExportSequenceViewItems.cpp" line="103"/>
        <source>Export sequences by &apos;db_xref&apos;</source>
        <translation type="unfinished">Экспортировать последовательности по &apos;db_xref&apos;</translation>
    </message>
    <message>
        <location filename="../src/ExportSequenceViewItems.cpp" line="205"/>
        <source>Fetch sequences from remote database</source>
        <translation type="unfinished">Загрузить последовательности</translation>
    </message>
    <message>
        <location filename="../src/ExportSequenceViewItems.cpp" line="208"/>
        <source>Fetch sequences by &apos;id&apos; %1</source>
        <translation type="unfinished">Загрузить по &apos;id&apos; %1</translation>
    </message>
    <message>
        <location filename="../src/ExportSequenceViewItems.cpp" line="212"/>
        <source>Fetch sequences by &apos;accession&apos; %1</source>
        <translation type="unfinished">Загрузить по &apos;accsession&apos; %1</translation>
    </message>
    <message>
        <location filename="../src/ExportSequenceViewItems.cpp" line="216"/>
        <source>Fetch sequences by &apos;db_xref&apos; %1</source>
        <translation type="unfinished">Загрузить по &apos;db_xref&apos; %1</translation>
    </message>
    <message>
        <location filename="../src/ExportSequenceViewItems.cpp" line="567"/>
        <source>Create alignment</source>
        <translation type="unfinished">Создать выравнивание</translation>
    </message>
    <message>
        <location filename="../src/ExportSequenceViewItems.cpp" line="568"/>
        <source>Save alignment to file</source>
        <translation type="unfinished">Сохранить выравнивание в файл</translation>
    </message>
    <message>
        <source>Make an alignment of translated sequence</source>
        <translation type="obsolete">Выровнять транслированные последовательности</translation>
    </message>
    <message>
        <location filename="../src/ExportSequenceViewItems.cpp" line="239"/>
        <location filename="../src/ExportSequenceViewItems.cpp" line="387"/>
        <source>No annotations selected!</source>
        <translation>Сначала выберите аннотации!</translation>
    </message>
    <message>
        <location filename="../src/ExportSequenceViewItems.cpp" line="325"/>
        <source>No sequence regions selected!</source>
        <translation>Нет выбранных участков!</translation>
    </message>
    <message>
        <location filename="../src/ExportSequenceViewItems.cpp" line="437"/>
        <source>At least 2 annotations are required</source>
        <translation type="unfinished">Нужно выбрать хотя бы 2 аннотации</translation>
    </message>
    <message>
        <location filename="../src/ExportSequenceViewItems.cpp" line="455"/>
        <source>Different sequence alphabets</source>
        <translation type="unfinished">Несопоставимые алфавиты</translation>
    </message>
    <message>
        <location filename="../src/ExportSequenceViewItems.cpp" line="514"/>
        <source>At least 2 sequences required</source>
        <translation>Необходимо как минимум 2 последовательности</translation>
    </message>
    <message>
        <location filename="../src/ExportSequenceViewItems.cpp" line="446"/>
        <source>No sequence object found</source>
        <translation>Последовательность недоступна</translation>
    </message>
    <message>
        <source>Different alphabets</source>
        <translation type="obsolete">Алфавиты последовательностей не совпадают</translation>
    </message>
    <message>
        <location filename="../src/ExportSequenceViewItems.cpp" line="472"/>
        <location filename="../src/ExportSequenceViewItems.cpp" line="531"/>
        <source>Alignment is too large</source>
        <translation>Слишком большой размер выравнивания</translation>
    </message>
    <message>
        <location filename="../src/ExportSequenceViewItems.cpp" line="508"/>
        <source>Can&apos;t derive alignment alphabet</source>
        <translation>Невозможно определить алфавит выравнивания</translation>
    </message>
</context>
<context>
    <name>U2::CSVColumnConfigurationDialog</name>
    <message>
        <location filename="../src/CSVColumnConfigurationDialog.cpp" line="66"/>
        <source>Invalid qualifier name!</source>
        <translation>Неправильное имя квалификатора!</translation>
    </message>
</context>
<context>
    <name>U2::DNAExportPlugin</name>
    <message>
        <source>dna_export_name</source>
        <translation type="obsolete">Экспорт</translation>
    </message>
    <message>
        <source>dna_export_desc</source>
        <translation type="obsolete">Поддержка экспорта последовательностей и выравниваний</translation>
    </message>
    <message>
        <location filename="../src/DNAExportPlugin.cpp" line="23"/>
        <source>DNA export</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/DNAExportPlugin.cpp" line="23"/>
        <source>Export and import support for DNA &amp; protein sequences</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::DNAExportService</name>
    <message>
        <source>dna_export_service_name</source>
        <translation type="obsolete">Экспорт</translation>
    </message>
    <message>
        <source>dna_export_service_desc</source>
        <translation type="obsolete">Экспорт последовательностей</translation>
    </message>
    <message>
        <location filename="../src/DNAExportPlugin.cpp" line="48"/>
        <source>DNA export service</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/DNAExportPlugin.cpp" line="48"/>
        <source>Export and import support for DNA &amp; protein sequences</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::ExportAlignmentTask</name>
    <message>
        <location filename="../src/ExportTasks.cpp" line="58"/>
        <source>Export alignment to &apos;%1&apos;</source>
        <translation>Экспорт выравнивания в &apos;%1&apos;</translation>
    </message>
</context>
<context>
    <name>U2::ExportAnnotationSequenceSubTask</name>
    <message>
        <location filename="../src/ExportSequenceTask.cpp" line="240"/>
        <source>Extract annotation regions</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::ExportAnnotationSequenceTask</name>
    <message>
        <location filename="../src/ExportSequenceTask.cpp" line="224"/>
        <source>Export annotations</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::ExportAnnotations2CSVDialog</name>
    <message>
        <source>Export annotations to CSV</source>
        <translation type="obsolete">Экспорт аннотаций в CSV</translation>
    </message>
    <message>
        <source>Export to file:</source>
        <translation type="obsolete">Записать в файл:</translation>
    </message>
    <message>
        <source>Save sequences under annotations</source>
        <translation type="obsolete">Сохранить последовательности под аннотациями</translation>
    </message>
    <message>
        <source>CSV files (*.csv);;All files (*)</source>
        <translation type="obsolete">Файлы CSV (*.csv);;Все файлы (*)</translation>
    </message>
</context>
<context>
    <name>U2::ExportAnnotations2CSVTask</name>
    <message>
        <location filename="../src/ExportAnnotations2CSVTask.cpp" line="20"/>
        <source>Export2CSV</source>
        <translation>Экспорт в CSV</translation>
    </message>
    <message>
        <location filename="../src/ExportAnnotations2CSVTask.cpp" line="56"/>
        <source>No IO adapter found for URL: %1</source>
        <translation>Не найден IO-адаптер для URL: %1</translation>
    </message>
    <message>
        <location filename="../src/ExportAnnotations2CSVTask.cpp" line="68"/>
        <source>Group</source>
        <translation>Группа</translation>
    </message>
    <message>
        <location filename="../src/ExportAnnotations2CSVTask.cpp" line="69"/>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <location filename="../src/ExportAnnotations2CSVTask.cpp" line="70"/>
        <source>Start</source>
        <translation>Начало</translation>
    </message>
    <message>
        <location filename="../src/ExportAnnotations2CSVTask.cpp" line="71"/>
        <source>End</source>
        <translation>Конец</translation>
    </message>
    <message>
        <location filename="../src/ExportAnnotations2CSVTask.cpp" line="72"/>
        <source>Length</source>
        <translation>Длина</translation>
    </message>
    <message>
        <location filename="../src/ExportAnnotations2CSVTask.cpp" line="93"/>
        <source>Complementary</source>
        <translation type="unfinished">Комплементарная</translation>
    </message>
    <message>
        <source>Complement</source>
        <translation>Комплементарная</translation>
    </message>
    <message>
        <location filename="../src/ExportAnnotations2CSVTask.cpp" line="75"/>
        <source>Sequence</source>
        <translation>Последовательность</translation>
    </message>
    <message>
        <location filename="../src/ExportAnnotations2CSVTask.cpp" line="102"/>
        <source>yes</source>
        <translation>да</translation>
    </message>
    <message>
        <location filename="../src/ExportAnnotations2CSVTask.cpp" line="104"/>
        <source>no</source>
        <translation>нет</translation>
    </message>
</context>
<context>
    <name>U2::ExportAnnotationsDialog</name>
    <message>
        <location filename="../src/ui/ExportAnnotationsDialog.ui" line="14"/>
        <source>Export annotations</source>
        <translation>Экспортировать аннотации</translation>
    </message>
    <message>
        <location filename="../src/ui/ExportAnnotationsDialog.ui" line="25"/>
        <source>Export to file:</source>
        <translation>Записать в файл:</translation>
    </message>
    <message>
        <location filename="../src/ui/ExportAnnotationsDialog.ui" line="37"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../src/ui/ExportAnnotationsDialog.ui" line="49"/>
        <source>File format:</source>
        <translation>Формат файла:</translation>
    </message>
    <message>
        <location filename="../src/ui/ExportAnnotationsDialog.ui" line="58"/>
        <source>Save sequences under annotations</source>
        <translation>Сохранить последовательности под аннотациями</translation>
    </message>
    <message>
        <location filename="../src/ExportAnnotationsDialog.cpp" line="100"/>
        <source>Select file to save annotations</source>
        <translation>Выберите файл для сохранения аннотаций</translation>
    </message>
</context>
<context>
    <name>U2::ExportChromatogramDialog</name>
    <message>
        <location filename="../src/ExportChromatogramDialog.cpp" line="36"/>
        <source>Select a file</source>
        <translation type="unfinished">Выберите файл</translation>
    </message>
    <message>
        <location filename="../src/ExportChromatogramDialog.cpp" line="47"/>
        <source>File name is empty!</source>
        <translation type="unfinished">Не указано имя файла!</translation>
    </message>
</context>
<context>
    <name>U2::ExportDNAChromatogramTask</name>
    <message>
        <location filename="../src/ExportTasks.cpp" line="162"/>
        <source>Export chromatogram to SCF</source>
        <translation type="unfinished">Экспорт хроматограммы в SCF</translation>
    </message>
</context>
<context>
    <name>U2::ExportMSA2MSADialog</name>
    <message>
        <location filename="../src/ui/ExportMSA2MSADialog.ui" line="20"/>
        <source>Dialog</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportMSA2MSADialog.ui" line="28"/>
        <source>Export to file</source>
        <translation>Записать в файл</translation>
    </message>
    <message>
        <location filename="../src/ui/ExportMSA2MSADialog.ui" line="38"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportMSA2MSADialog.ui" line="45"/>
        <source>File format to use</source>
        <translation>Используемый формат файла</translation>
    </message>
    <message>
        <location filename="../src/ui/ExportMSA2MSADialog.ui" line="55"/>
        <source>Amino translation</source>
        <translation>Таблица трансляции</translation>
    </message>
    <message>
        <location filename="../src/ui/ExportMSA2MSADialog.ui" line="67"/>
        <source>Add document to the project</source>
        <translation>Добавить документ к проекту</translation>
    </message>
    <message>
        <location filename="../src/ui/ExportMSA2MSADialog.ui" line="77"/>
        <source>Export range</source>
        <translation>Рамки экспорта</translation>
    </message>
    <message>
        <location filename="../src/ui/ExportMSA2MSADialog.ui" line="83"/>
        <source>Whole alignment</source>
        <translation>Всё выравнивание</translation>
    </message>
    <message>
        <location filename="../src/ui/ExportMSA2MSADialog.ui" line="93"/>
        <source>Selected rows</source>
        <translation>Выбранные строки</translation>
    </message>
    <message>
        <location filename="../src/ui/ExportMSA2MSADialog.ui" line="134"/>
        <source>Export</source>
        <translation>Экспорт</translation>
    </message>
    <message>
        <location filename="../src/ui/ExportMSA2MSADialog.ui" line="141"/>
        <source>Cancel</source>
        <translation>Отменить</translation>
    </message>
    <message>
        <location filename="../src/ExportMSA2MSADialog.cpp" line="33"/>
        <source>Export alignment</source>
        <translation>Экспорт выравнивания</translation>
    </message>
    <message>
        <location filename="../src/ExportMSA2MSADialog.cpp" line="65"/>
        <source>File is empty</source>
        <translation>Не указано имя файла</translation>
    </message>
</context>
<context>
    <name>U2::ExportMSA2MSATask</name>
    <message>
        <location filename="../src/ExportTasks.cpp" line="109"/>
        <source>Export alignment to alignment: %1</source>
        <translation>Экспортировать выравнивание в выравнивание: %1</translation>
    </message>
    <message>
        <location filename="../src/ExportTasks.cpp" line="135"/>
        <source>Out of memory</source>
        <translation>Ошибка выделения памяти</translation>
    </message>
</context>
<context>
    <name>U2::ExportMSA2SequencesDialog</name>
    <message>
        <location filename="../src/ui/ExportMSA2SequencesDialog.ui" line="14"/>
        <source>Convert alignment to separate sequences</source>
        <translation>Конвертировать выравнивание в разные последовательности</translation>
    </message>
    <message>
        <location filename="../src/ui/ExportMSA2SequencesDialog.ui" line="25"/>
        <source>Export to file</source>
        <translation>Записать в файл</translation>
    </message>
    <message>
        <location filename="../src/ui/ExportMSA2SequencesDialog.ui" line="35"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportMSA2SequencesDialog.ui" line="42"/>
        <source>File format to use</source>
        <translation>Используемый формат файла</translation>
    </message>
    <message>
        <location filename="../src/ui/ExportMSA2SequencesDialog.ui" line="54"/>
        <source>Add document to the project</source>
        <translation>Добавить документ к проекту</translation>
    </message>
    <message>
        <location filename="../src/ui/ExportMSA2SequencesDialog.ui" line="64"/>
        <source>Gap characters (&apos;-&apos;)</source>
        <translation>Символы пропуска (&quot;-&quot;)</translation>
    </message>
    <message>
        <location filename="../src/ui/ExportMSA2SequencesDialog.ui" line="70"/>
        <source>Keep</source>
        <translation>Сохранять</translation>
    </message>
    <message>
        <location filename="../src/ui/ExportMSA2SequencesDialog.ui" line="80"/>
        <source>Trim</source>
        <translation>Удалять</translation>
    </message>
    <message>
        <location filename="../src/ui/ExportMSA2SequencesDialog.ui" line="118"/>
        <source>Export</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportMSA2SequencesDialog.ui" line="128"/>
        <source>Cancel</source>
        <translation>Отменить</translation>
    </message>
    <message>
        <location filename="../src/ExportMSA2SequencesDialog.cpp" line="37"/>
        <source>File name is empty!</source>
        <translation>Не указано имя файла!</translation>
    </message>
</context>
<context>
    <name>U2::ExportMSA2SequencesTask</name>
    <message>
        <location filename="../src/ExportTasks.cpp" line="78"/>
        <source>Export alignment to sequence: %1</source>
        <translation>Экспорт выравнивания в последовательность: %1</translation>
    </message>
</context>
<context>
    <name>U2::ExportProjectViewItemsContoller</name>
    <message>
        <location filename="../src/ExportProjectViewItems.cpp" line="49"/>
        <source>Export sequences</source>
        <translation>Экспорт последовательностей</translation>
    </message>
    <message>
        <location filename="../src/ExportProjectViewItems.cpp" line="52"/>
        <source>Export sequences as alignment</source>
        <translation>Экспорт последовательностей как выравнивания</translation>
    </message>
    <message>
        <location filename="../src/ExportProjectViewItems.cpp" line="55"/>
        <source>Export alignment to sequence format</source>
        <translation>Экспорт выравнивания в последовательность</translation>
    </message>
    <message>
        <location filename="../src/ExportProjectViewItems.cpp" line="58"/>
        <source>Export nucleic alignment to amino translation</source>
        <translation>Экспортировать и транслировать выравнивание</translation>
    </message>
    <message>
        <location filename="../src/ExportProjectViewItems.cpp" line="61"/>
        <source>Import annotations from CSV file</source>
        <translation>Импортировать аннотации из CSV</translation>
    </message>
    <message>
        <location filename="../src/ExportProjectViewItems.cpp" line="64"/>
        <source>Export chromatogram to SCF</source>
        <translation type="unfinished">Экспорт хроматограммы в SCF</translation>
    </message>
    <message>
        <location filename="../src/ExportProjectViewItems.cpp" line="67"/>
        <source>Export annotations</source>
        <translation>Экспортировать аннотации</translation>
    </message>
    <message>
        <location filename="../src/ExportProjectViewItems.cpp" line="92"/>
        <location filename="../src/ExportProjectViewItems.cpp" line="98"/>
        <location filename="../src/ExportProjectViewItems.cpp" line="111"/>
        <location filename="../src/ExportProjectViewItems.cpp" line="119"/>
        <source>Export</source>
        <translation>Экспорт</translation>
    </message>
    <message>
        <location filename="../src/ExportProjectViewItems.cpp" line="132"/>
        <source>Import</source>
        <translation>Импорт</translation>
    </message>
    <message>
        <location filename="../src/ExportProjectViewItems.cpp" line="177"/>
        <location filename="../src/ExportProjectViewItems.cpp" line="238"/>
        <source>No sequence objects selected!</source>
        <translation>Выделите один или более объектов!</translation>
    </message>
    <message>
        <location filename="../src/ExportProjectViewItems.cpp" line="270"/>
        <location filename="../src/ExportProjectViewItems.cpp" line="293"/>
        <source>Select one alignment object to export</source>
        <translation>Выберите один объект выравнивания</translation>
    </message>
    <message>
        <location filename="../src/ExportProjectViewItems.cpp" line="342"/>
        <source>Select one chromatogram object to export</source>
        <translation type="unfinished">Выберите один объект для экспорта</translation>
    </message>
    <message>
        <location filename="../src/ExportProjectViewItems.cpp" line="378"/>
        <source>Select one annotation object to export</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ExportProjectViewItems.cpp" line="387"/>
        <source>Selected object doesn&apos;t have annotations</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::ExportSequenceTask</name>
    <message>
        <location filename="../src/ExportSequenceTask.cpp" line="25"/>
        <source>Export sequence to &apos;%1&apos;</source>
        <translation type="unfinished">Экспорт последовательностей в &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../src/ExportSequenceTask.cpp" line="41"/>
        <source>Complement translation not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ExportSequenceTask.cpp" line="70"/>
        <source>Amino  translation not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ExportSequenceTask.cpp" line="104"/>
        <source>Back-translation not found</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::ExportSequences2MSADialog</name>
    <message>
        <location filename="../src/ui/ExportSequences2MSADialog.ui" line="14"/>
        <source>Export sequences as alignment</source>
        <translation>Экспорт последовательностей как выравнивания</translation>
    </message>
    <message>
        <location filename="../src/ui/ExportSequences2MSADialog.ui" line="25"/>
        <source>Export to file</source>
        <translation>Записать в файл</translation>
    </message>
    <message>
        <location filename="../src/ui/ExportSequences2MSADialog.ui" line="35"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportSequences2MSADialog.ui" line="42"/>
        <source>File format to use</source>
        <translation>Используемый формат файла</translation>
    </message>
    <message>
        <location filename="../src/ui/ExportSequences2MSADialog.ui" line="54"/>
        <source>Add document to the project</source>
        <translation>Добавить документ к проекту</translation>
    </message>
    <message>
        <location filename="../src/ui/ExportSequences2MSADialog.ui" line="92"/>
        <source>Export</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <location filename="../src/ui/ExportSequences2MSADialog.ui" line="102"/>
        <source>Cancel</source>
        <translation>Отменить</translation>
    </message>
    <message>
        <location filename="../src/ExportSequences2MSADialog.cpp" line="37"/>
        <source>File name is empty!</source>
        <translation>Не указано имя файла!</translation>
    </message>
</context>
<context>
    <name>U2::ExportSequencesDialog</name>
    <message>
        <location filename="../src/ui/ExportSequencesDialog.ui" line="20"/>
        <source>Export selected sequences</source>
        <translation>Экспорт выбранных последовательностей</translation>
    </message>
    <message>
        <location filename="../src/ui/ExportSequencesDialog.ui" line="31"/>
        <source>Export to file</source>
        <translation>Записать в файл</translation>
    </message>
    <message>
        <location filename="../src/ui/ExportSequencesDialog.ui" line="41"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportSequencesDialog.ui" line="48"/>
        <source>File format to use</source>
        <translation>Используемый формат файла</translation>
    </message>
    <message>
        <location filename="../src/ui/ExportSequencesDialog.ui" line="60"/>
        <source>Export with annotations</source>
        <translation>Экспортировать с аннотациями</translation>
    </message>
    <message>
        <location filename="../src/ui/ExportSequencesDialog.ui" line="67"/>
        <source>Add document to the project</source>
        <translation>Добавить документ к проекту</translation>
    </message>
    <message>
        <location filename="../src/ui/ExportSequencesDialog.ui" line="77"/>
        <source>Convertion options</source>
        <translation>Настройки трансляции</translation>
    </message>
    <message>
        <location filename="../src/ui/ExportSequencesDialog.ui" line="83"/>
        <source>Save direct strand</source>
        <translation>Сохранять прямую</translation>
    </message>
    <message>
        <location filename="../src/ui/ExportSequencesDialog.ui" line="93"/>
        <source>Save complement strand</source>
        <translation>Сохранять комплементарную</translation>
    </message>
    <message>
        <location filename="../src/ui/ExportSequencesDialog.ui" line="100"/>
        <source>Save both strands</source>
        <translation>Сохранять обе</translation>
    </message>
    <message>
        <location filename="../src/ui/ExportSequencesDialog.ui" line="107"/>
        <source>Translate to amino alphabet</source>
        <translation>Транслировать</translation>
    </message>
    <message>
        <location filename="../src/ui/ExportSequencesDialog.ui" line="117"/>
        <source>Save all amino frames</source>
        <translation>Сохранять все рамки трансляции</translation>
    </message>
    <message>
        <source>Use this translation table</source>
        <translation type="obsolete">Использовать таблицу трансляции</translation>
    </message>
    <message>
        <location filename="../src/ui/ExportSequencesDialog.ui" line="147"/>
        <source>Back translation options</source>
        <translation>Настройки обратной трансляции</translation>
    </message>
    <message>
        <location filename="../src/ui/ExportSequencesDialog.ui" line="153"/>
        <source>Translate back to nucleic alphabet</source>
        <translation>Транслировать обратно в алфавит нуклеотидов</translation>
    </message>
    <message>
        <location filename="../src/ui/ExportSequencesDialog.ui" line="165"/>
        <source>Most frequently used codons</source>
        <translation>Наиболее часто используемые кодоны</translation>
    </message>
    <message>
        <location filename="../src/ui/ExportSequencesDialog.ui" line="192"/>
        <source>Organism:</source>
        <translation>Организм:</translation>
    </message>
    <message>
        <location filename="../src/ui/ExportSequencesDialog.ui" line="251"/>
        <source>Save as separate sequences</source>
        <translation>Сохр. послед. раздельно</translation>
    </message>
    <message>
        <location filename="../src/ui/ExportSequencesDialog.ui" line="178"/>
        <source>Frequency distribution</source>
        <translation>Частотное распределение</translation>
    </message>
    <message>
        <location filename="../src/ui/ExportSequencesDialog.ui" line="137"/>
        <source>Use custom translation table</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportSequencesDialog.ui" line="214"/>
        <source>Merge options</source>
        <translation>Настройки группировки последовательностей</translation>
    </message>
    <message>
        <location filename="../src/ui/ExportSequencesDialog.ui" line="222"/>
        <source>Add gap symbols between sequences</source>
        <translation>Добавлять пробелы между последовательностями</translation>
    </message>
    <message>
        <location filename="../src/ui/ExportSequencesDialog.ui" line="244"/>
        <source>Merge sequences</source>
        <translation>Объединять последовательности</translation>
    </message>
    <message>
        <source>Save as separate sequencs</source>
        <translation type="obsolete">Сохранять отдельными</translation>
    </message>
    <message>
        <location filename="../src/ui/ExportSequencesDialog.ui" line="292"/>
        <source>Export</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <location filename="../src/ui/ExportSequencesDialog.ui" line="299"/>
        <source>Cancel</source>
        <translation>Отменить</translation>
    </message>
    <message>
        <location filename="../src/ExportSequencesDialog.cpp" line="37"/>
        <source>Export sequences</source>
        <translation>Экспорт последовательностей</translation>
    </message>
    <message>
        <location filename="../src/ExportSequencesDialog.cpp" line="130"/>
        <source>Select organism</source>
        <translation>Выберите организм</translation>
    </message>
    <message>
        <location filename="../src/ExportSequencesDialog.cpp" line="198"/>
        <source>File is empty</source>
        <translation>Не указано имя файла</translation>
    </message>
    <message>
        <location filename="../src/ExportSequencesDialog.cpp" line="203"/>
        <source>Organism for back translation not specified</source>
        <translation>Не выбран организм для обратной трансляции</translation>
    </message>
</context>
<context>
    <name>U2::ExportSequencesTask</name>
    <message>
        <source>Export sequence to &apos;%1&apos;</source>
        <translation type="obsolete">Экспорт последовательностей в &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Complement translator not found</source>
        <translation type="obsolete">Не найдена таблица комплементарной трансляции</translation>
    </message>
    <message>
        <source>Out of memory</source>
        <translation type="obsolete">Ошибка выделения памяти</translation>
    </message>
</context>
<context>
    <name>U2::GTest</name>
    <message>
        <location filename="../src/DNAExportPluginTests.cpp" line="93"/>
        <source>Unable to create temporary file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/DNAExportPluginTests.cpp" line="112"/>
        <source>Invalid translation table num: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/DNAExportPluginTests.cpp" line="128"/>
        <location filename="../src/DNAExportPluginTests.cpp" line="134"/>
        <source>Invalid base : %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/DNAExportPluginTests.cpp" line="147"/>
        <location filename="../src/DNAExportPluginTests.cpp" line="184"/>
        <location filename="../src/DNAExportPluginTests.cpp" line="207"/>
        <source>context not found %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/DNAExportPluginTests.cpp" line="153"/>
        <location filename="../src/DNAExportPluginTests.cpp" line="190"/>
        <location filename="../src/DNAExportPluginTests.cpp" line="213"/>
        <source>container of object with type &quot;%1&quot; is empty</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/DNAExportPluginTests.cpp" line="220"/>
        <source>Unexpected alignment length %1, expected %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/DNAExportPluginTests.cpp" line="225"/>
        <source>Unexpected alignment size %1, expected %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/DNAExportPluginTests.cpp" line="234"/>
        <source>Invalid name for row %1: %2, expected %3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/DNAExportPluginTests.cpp" line="239"/>
        <source>Invalid char at row %1 column %2: %3, expected %4</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::GetSequenceByIdDialog</name>
    <message>
        <location filename="../src/GetSequenceByIdDialog.cpp" line="24"/>
        <source>Select directory to save</source>
        <translation type="unfinished">Папка для сохранения</translation>
    </message>
</context>
<context>
    <name>U2::ImportAnnotationsFromCSVDialog</name>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVDialog.cpp" line="57"/>
        <source>Save imported annotations to</source>
        <translation>Выберите файл для сохранения аннотаций</translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVDialog.cpp" line="86"/>
        <source>//The script parses input line
 // and returns an array of parsed elements as the result
var %1; //input line
var %2; //parsed line number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVDialog.cpp" line="130"/>
        <source>Invalid start position/end position/length configuration!</source>
        <translation>Неправильная конфигурация координат аннотации!</translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVDialog.cpp" line="134"/>
        <source>Multiple columns are used as a name!</source>
        <translation>В качестве имени аннотации можно выбрать только один столбец!</translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVDialog.cpp" line="282"/>
        <source>Column separator value: [%1], hex: [%2], length: %3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVDialog.cpp" line="348"/>
        <source>Script is empty</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVDialog.cpp" line="363"/>
        <source>Output file format is not set!</source>
        <translation>Не задан формат файла с аннотациями!</translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVDialog.cpp" line="358"/>
        <source>Output file name is not set!</source>
        <translation>Не задано имя файла с аннотациями!</translation>
    </message>
    <message>
        <source>Column separator is not set!</source>
        <translation type="obsolete">Не задан символ разделитель столбцов!</translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVDialog.cpp" line="138"/>
        <source>Invalid default annotation name!</source>
        <translation>Неправильное имя аннотации по умолчанию!</translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVDialog.cpp" line="259"/>
        <source>Failed to guess separator sequence!</source>
        <translation>Не удалось определить разделителный символ !</translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVDialog.cpp" line="280"/>
        <source>Column separator</source>
        <translation>Разделитель столбцов</translation>
    </message>
    <message>
        <source>Column separator value: [%1], length: %2</source>
        <translation type="obsolete">Значение разделителя: [%1], длина: [%2]</translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVDialog.cpp" line="301"/>
        <source>Select CSV file to read</source>
        <translation>Выберите файл со столбцами</translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVDialog.cpp" line="315"/>
        <source>Enter input CSV file name</source>
        <translation>Укажите исходный файл с данными</translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVDialog.cpp" line="342"/>
        <source>Separator value is not set</source>
        <translation>Не задан символ разделитель столбцов</translation>
    </message>
    <message>
        <source>Enter output file name</source>
        <translation type="obsolete">Введите имя файла для сохранения аннотаций</translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVDialog.cpp" line="445"/>
        <source>[ignored]</source>
        <translation>[не используется]</translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVDialog.cpp" line="448"/>
        <source>[qualifier %1]</source>
        <translation>[квалификатор: %1]</translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVDialog.cpp" line="451"/>
        <source>[name]</source>
        <translation>[имя]</translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVDialog.cpp" line="455"/>
        <source>[start position with offset %1]</source>
        <translation>[начальная позиция, смещение %1]</translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVDialog.cpp" line="457"/>
        <source>[start position]</source>
        <translation>[начальная позиция]</translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVDialog.cpp" line="462"/>
        <source>[end position (inclusive)]</source>
        <translation>[конечная позиция (включительно)]</translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVDialog.cpp" line="464"/>
        <source>[end position]</source>
        <translation>[конечная позиция]</translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVDialog.cpp" line="468"/>
        <source>[length]</source>
        <translation>[длина]</translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVDialog.cpp" line="472"/>
        <source>[complement]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVDialog.cpp" line="474"/>
        <source>[complement if &apos;%1&apos;]</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::ImportAnnotationsFromCSVTask</name>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVTask.cpp" line="29"/>
        <source>Import annotations from CSV</source>
        <translation>Импортировать аннотации из CSV</translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVTask.cpp" line="105"/>
        <source>Annotations can&apos;t be added to the document %1</source>
        <translation>Аннотации не могут быть добавлены к документу %1</translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVTask.cpp" line="109"/>
        <source>Document is locked and can&apos;t be modified %1</source>
        <translation>Документ заблокирован и не может быть изменён %1</translation>
    </message>
</context>
<context>
    <name>U2::LocalWorkflow::ImportPhredQualityPrompter</name>
    <message>
        <location filename="../src/ImportQualityScoresWorker.cpp" line="82"/>
        <source> from &lt;u&gt;%1&lt;/u&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ImportQualityScoresWorker.cpp" line="84"/>
        <source>unset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ImportQualityScoresWorker.cpp" line="86"/>
        <source>Import PHRED quality scores in file %1  to the sequences %2 and send the sequences to the output.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::LocalWorkflow::ImportPhredQualityWorker</name>
    <message>
        <location filename="../src/ImportQualityScoresWorker.cpp" line="32"/>
        <source>DNA sequences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ImportQualityScoresWorker.cpp" line="33"/>
        <source>The PHRED scores will be imported to these sequences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ImportQualityScoresWorker.cpp" line="34"/>
        <source>DNA sequences with imported qualities</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ImportQualityScoresWorker.cpp" line="35"/>
        <source>These sequences have quality scores.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ImportQualityScoresWorker.cpp" line="44"/>
        <source>PHRED input</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ImportQualityScoresWorker.cpp" line="45"/>
        <source>Path to file with PHRED quality scores.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ImportQualityScoresWorker.cpp" line="46"/>
        <source>Quality format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ImportQualityScoresWorker.cpp" line="47"/>
        <source>Choose format to encode quality scores.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ImportQualityScoresWorker.cpp" line="52"/>
        <source>Import PHRED qualities</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ImportQualityScoresWorker.cpp" line="53"/>
        <source>Add corresponding PHRED quality scores to the sequences.
You can use this worker to convert .fasta and .qual pair to fastq format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ImportQualityScoresWorker.cpp" line="116"/>
        <source>Sequence list is empty.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ImportQualityScoresWorker.cpp" line="142"/>
        <source>Import of qualities is finished.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::LocalWorkflow::WriteAnnotationsPrompter</name>
    <message>
        <location filename="../src/WriteAnnotationsWorker.cpp" line="173"/>
        <source>unset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/WriteAnnotationsWorker.cpp" line="181"/>
        <source>Save all annotations from &lt;u&gt;%1&lt;/u&gt; to %2 in &lt;u&gt;%3&lt;/u&gt; format</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::LocalWorkflow::WriteAnnotationsWorker</name>
    <message>
        <location filename="../src/WriteAnnotationsWorker.cpp" line="54"/>
        <source>Unrecognized formatId: &apos;%1&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/WriteAnnotationsWorker.cpp" line="60"/>
        <source>Unspecified URL to write %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/WriteAnnotationsWorker.cpp" line="70"/>
        <source>Annotations name not specified. Default value used: &apos;%1&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/WriteAnnotationsWorker.cpp" line="116"/>
        <source>Input annotations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/WriteAnnotationsWorker.cpp" line="117"/>
        <source>Input annotations which will be written to output file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/WriteAnnotationsWorker.cpp" line="134"/>
        <source>Annotations name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/WriteAnnotationsWorker.cpp" line="135"/>
        <source>Object name of saving annotations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/WriteAnnotationsWorker.cpp" line="140"/>
        <source>Write annotations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/WriteAnnotationsWorker.cpp" line="141"/>
        <source>Writes all supplied annotations to file(s) in selected formatId.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::MSAExportContext</name>
    <message>
        <location filename="../src/ExportAlignmentViewItems.cpp" line="59"/>
        <source>Export amino translation of alignment rows...</source>
        <translation>Экспортировать трансляцию строк выравнивания...</translation>
    </message>
</context>
<context>
    <name>U2::ReadCSVAsAnnotationsTask</name>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVTask.cpp" line="155"/>
        <source>Parse CSV file %1</source>
        <translation>Разобрать CSV %1</translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVTask.cpp" line="210"/>
        <source>Invalid annotation name: &apos;%1&apos;</source>
        <translation>Неправильное имя аннотации: &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVTask.cpp" line="218"/>
        <source>Start offset is not numeric: &apos;%1&apos;</source>
        <translation>Смещение начала не является числом: &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVTask.cpp" line="225"/>
        <source>End offset is not numeric: &apos;%1&apos;</source>
        <translation>Смещение конца не является числом: &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVTask.cpp" line="232"/>
        <source>Length is not numeric: &apos;%1&apos;</source>
        <translation>Длина не является числом: &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVTask.cpp" line="267"/>
        <source>Invalid location: start: %1  len: %2, in line :%3, ignoring</source>
        <translation>Неверная позиция: начало: %1  длина: %2, в строке :%3, пропуск</translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVTask.cpp" line="275"/>
        <source>Can&apos;t parse line: &apos;%1&apos;, error = %2, ignoring</source>
        <translation>Невозможно разобрать строку: &apos;%1&apos;, ошибка = %2, пропуск</translation>
    </message>
    <message>
        <location filename="../src/ImportAnnotationsFromCSVTask.cpp" line="354"/>
        <source>Script result is not an array of strings!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>getSequenceByIdDialog</name>
    <message>
        <location filename="../src/ui/GetSequenceByIdDialog.ui" line="14"/>
        <source>Get sequences by ID</source>
        <translation type="unfinished">Загрузить последовательности по ШВ</translation>
    </message>
    <message>
        <location filename="../src/ui/GetSequenceByIdDialog.ui" line="22"/>
        <source>The sequences from selected BLAST results will be downloaded from
 NCBI Genbank by their GI identifier
</source>
        <translation type="unfinished">Последовательности из выбранных аннотаций буду загружены из NCBI Genbank по идентификатору</translation>
    </message>
    <message>
        <location filename="../src/ui/GetSequenceByIdDialog.ui" line="33"/>
        <source>Save to directctory:</source>
        <translation type="unfinished">Папка для сохранения:</translation>
    </message>
    <message>
        <location filename="../src/ui/GetSequenceByIdDialog.ui" line="43"/>
        <source>...</source>
        <translation type="unfinished">...</translation>
    </message>
    <message>
        <location filename="../src/ui/GetSequenceByIdDialog.ui" line="52"/>
        <source>Add to project</source>
        <translation type="unfinished">Добавить в проект</translation>
    </message>
</context>
</TS>
